==> gitlab_12.2.8.orig.tar.gz: gitlab-foss-v12.2.8/.gitlab/issue_templates/Security Release.md <==
<!--
# Read me first!

Set the title to: `Security Release: 12.2.X, 12.1.X, and 12.0.X`
-->

## Releases tasks

- https://gitlab.com/gitlab-org/release/docs/blob/master/general/security/release-manager.md
- https://gitlab.com/gitlab-org/release/docs/blob/master/general/security/developer.md
- https://gitlab.com/gitlab-org/release/docs/blob/master/general/security/security-engineer.md

## Version issues:

* 12.2.X: {release task link}
* 12.1.X: {release task link}
* 12.0.X: {release task link}

## Security Issues:

### CE

* {https://gitlab.com/gitlab-org/gitlab-ce/issues link}

### EE

* {https://gitlab.com/gitlab-org/gitlab-ee/issues link}

## Security Issues in dev.gitlab.org:

### CE

- {https://dev.gitlab.org/gitlab/gitlabhq/issues link}

| Version | MR |
|---------|----|
| 12.2 | {https://dev.gitlab.org/gitlab/gitlabhq/merge_requests/ link} |
| 12.1 | {https://dev.gitlab.org/gitlab/gitlabhq/merge_requests/ link} |
| 12.0 | {https://dev.gitlab.org/gitlab/gitlabhq/merge_requests/ link} |
| master | {https://dev.gitlab.org/gitlab/gitlabhq/merge_requests/ link} |



### EE

* {https://dev.gitlab.org/gitlab/gitlabhq/issues/ link}


| Version | MR |
|---------|----|
| 12.2 | {https://dev.gitlab.org/gitlab/gitlab-ee/merge_requests/ link} |
| 12.1 | {https://dev.gitlab.org/gitlab/gitlab-ee/merge_requests/ link} |
| 12.0 | {https://dev.gitlab.org/gitlab/gitlab-ee/merge_requests/ link} |
| master | {https://dev.gitlab.org/gitlab/gitlab-ee/merge_requests/ link} |


## QA
{QA issue link}

## Blog post

Dev: {https://dev.gitlab.org/gitlab/www-gitlab-com/merge_requests/ link}<br/>
gitlab.com: {https://gitlab.com/gitlab-com/www-gitlab-com/merge_requests/ link}

## Email notification
{https://gitlab.com/gitlab-com/marketing/general/issues/ link}

/label ~security
/confidential

==> gitlab_12.6.4.orig.tar.gz: gitlab-foss-v12.6.4/.gitlab/issue_templates/Security Release.md <==
<!--
# Read me first!

Set the title to: `Security Release: 12.2.X, 12.1.X, and 12.0.X`
-->

## Releases tasks

- https://gitlab.com/gitlab-org/release/docs/blob/master/general/security/release-manager.md
- https://gitlab.com/gitlab-org/release/docs/blob/master/general/security/developer.md
- https://gitlab.com/gitlab-org/release/docs/blob/master/general/security/security-engineer.md

## Version issues:

* 12.2.X: {release task link}
* 12.1.X: {release task link}
* 12.0.X: {release task link}

## Security Issues:

* {https://gitlab.com/gitlab-org/gitlab/issues link}

## Security Issues in dev.gitlab.org:

### CE

- {https://dev.gitlab.org/gitlab/gitlabhq/issues link}

| Version | MR |
|---------|----|
| 12.2 | {https://dev.gitlab.org/gitlab/gitlabhq/merge_requests/ link} |
| 12.1 | {https://dev.gitlab.org/gitlab/gitlabhq/merge_requests/ link} |
| 12.0 | {https://dev.gitlab.org/gitlab/gitlabhq/merge_requests/ link} |
| master | {https://dev.gitlab.org/gitlab/gitlabhq/merge_requests/ link} |



### EE

* {https://dev.gitlab.org/gitlab/gitlabhq/issues/ link}


| Version | MR |
|---------|----|
| 12.2 | {https://dev.gitlab.org/gitlab/gitlab-ee/merge_requests/ link} |
| 12.1 | {https://dev.gitlab.org/gitlab/gitlab-ee/merge_requests/ link} |
| 12.0 | {https://dev.gitlab.org/gitlab/gitlab-ee/merge_requests/ link} |
| master | {https://dev.gitlab.org/gitlab/gitlab-ee/merge_requests/ link} |


## QA
{QA issue link}

## Blog post

Dev: {https://dev.gitlab.org/gitlab/www-gitlab-com/merge_requests/ link}<br/>
gitlab.com: {https://gitlab.com/gitlab-com/www-gitlab-com/merge_requests/ link}

## Email notification
{https://gitlab.com/gitlab-com/marketing/general/issues/ link}

/label ~security
/confidential
